# IXON CDK Ingress

IXON CDK Ingress used in Cloud Functions for the IXON Cloud.

Learn more about how a machine builder can build their IoT portal using the IXON cloud on https://developer.ixon.cloud/.
